@@ -1,4 +1,5 @@
 import inspect
+import json
 
 from autoconf.class_path import get_class_path, get_class
 
@@ -47,14 +48,14 @@ class Dictable:
 
     @staticmethod
     def from_dict(
-            profile_dict
+            cls_dict
     ):
         """
-        Instantiate a GeometryProfile from its dictionary representation.
+        Instantiate an instance of a class from its dictionary representation.
 
         Parameters
         ----------
-        profile_dict
+        cls_dict
             A dictionary representation of the instance comprising a type
             field which contains the entire class path by which the type
             can be imported and constructor arguments.
@@ -62,24 +63,24 @@ class Dictable:
         Returns
         -------
         An instance of the geometry profile specified by the type field in
-        the profile_dict
+        the cls_dict
         """
         if isinstance(
-                profile_dict,
+                cls_dict,
                 list
         ):
             return list(map(
                 Dictable.from_dict,
-                profile_dict
+                cls_dict
             ))
         if not isinstance(
-                profile_dict,
+                cls_dict,
                 dict
         ):
-            return profile_dict
+            return cls_dict
 
         cls = get_class(
-            profile_dict.pop(
+            cls_dict.pop(
                 "type"
             )
         )
@@ -90,9 +91,43 @@ class Dictable:
                     value
                 )
                 for name, value
-                in profile_dict.items()
+                in cls_dict.items()
             }
         )
 
+    @classmethod
+    def from_json(cls, file_path: str) -> "Dictable":
+        """
+        Load the dictable object to a .json file, whereby all attributes are converted from the .json file's dictionary
+        representation to create the instance of the object
+
+        A json file of the instance can be created from the .json file via the `output_to_json` method.
+
+        Parameters
+        ----------
+        file_path
+            The path to the .json file that the dictionary representation of the object is loaded from.
+        """
+        with open(file_path, "r+") as f:
+            cls_dict = json.load(f)
+
+        return cls.from_dict(cls_dict=cls_dict)
+
+
+    def output_to_json(self, file_path: str):
+        """
+        Output the dictable object to a .json file, whereby all attributes are converted to a dictionary representation
+        first.
+
+        An instane of the object can be created from the .json file via the `from_json` method.
+
+        Parameters
+        ----------
+        file_path
+            The path to the .json file that the dictionary representation of the object is written too.
+        """
+        with open(file_path, "w+") as f:
+            json.dump(self.dict(), f, indent=4)
+
     def __eq__(self, other):
         return self.dict() == other.dict()
