@@ -28,12 +28,12 @@ class TestLabel:
         assert label_config["label"]["gamma"] == r"\gamma"
         assert label_config["label"]["contribution_factor"] == r"\omega0"
 
-    def test_subscript(self, label_config):
-        assert label_config["subscript"].family(EllProfile) == "l"
+    def test_superscript(self, label_config):
+        assert label_config["superscript"].family(EllProfile) == "l"
 
     def test_inheritance(self, label_config):
-        assert label_config["subscript"].family(EllGaussian) == "l"
+        assert label_config["superscript"].family(EllGaussian) == "l"
 
     def test_exception(self, label_config):
         with pytest.raises(KeyError):
-            label_config["subscript"].family(MockClass)
+            label_config["superscript"].family(MockClass)
